==> estateplat-common-1.2.4-20211019.054126-914-sources.jar: cn/gtmap/estateplat/model/exchange/national/newStandard/ZttGyJtcyNew.java <==
package cn.gtmap.estateplat.model.exchange.national.newStandard;

import cn.gtmap.estateplat.model.exchange.national.AccessData;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import java.io.Serializable;

/**
 * @author <a href="mailto:zhangyu@gtmap.cn">zhangyu</a>
 * @version 1.0, 2021/10/14
 * @description
 */
@XmlRootElement(name = "ZTT_GY_JTCY")
public class ZttGyJtcyNew implements Serializable, AccessData {
    final static String ysdm = "6003050000";
    private String bdcdyh;
    private String ywh;
    private Integer sxh;
    private String cbfbm;
    private String cyxm;
    private String jtgxdm;
    private String sfzhm;
    private String fzjg;
    private String sshy;
    private String gj;
    private String hjszss;
    private String xb;
    private String dh;
    private String dz;
    private String yb;
    private String gzdw;
    private String dzyj;
    private String sfgyr;
    private String bz;
    @XmlAttribute(name = "YSDM")
    public String getYsdm() {
        return ysdm;
    }

    @XmlAttribute(name = "BDCDYH")
    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }
    @XmlAttribute(name = "YWH")
    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }
    @XmlAttribute(name = "SXH")
    public Integer getSxh() {
        return sxh;
    }

    public void setSxh(Integer sxh) {
        this.sxh = sxh;
    }
    @XmlAttribute(name = "CBFBM")
    public String getCbfbm() {
        return cbfbm;
    }

    public void setCbfbm(String cbfbm) {
        this.cbfbm = cbfbm;
    }
    @XmlAttribute(name = "CYXM")
    public String getCyxm() {
        return cyxm;
    }

    public void setCyxm(String cyxm) {
        this.cyxm = cyxm;
    }
    @XmlAttribute(name = "JTGXDM")
    public String getJtgxdm() {
        return jtgxdm;
    }

    public void setJtgxdm(String jtgxdm) {
        this.jtgxdm = jtgxdm;
    }
    @XmlAttribute(name = "SFZHM")
    public String getSfzhm() {
        return sfzhm;
    }

    public void setSfzhm(String sfzhm) {
        this.sfzhm = sfzhm;
    }
    @XmlAttribute(name = "FZJG")
    public String getFzjg() {
        return fzjg;
    }

    public void setFzjg(String fzjg) {
        this.fzjg = fzjg;
    }
    @XmlAttribute(name = "SSHY")
    public String getSshy() {
        return sshy;
    }

    public void setSshy(String sshy) {
        this.sshy = sshy;
    }
    @XmlAttribute(name = "GJ")
    public String getGj() {
        return gj;
    }

    public void setGj(String gj) {
        this.gj = gj;
    }
    @XmlAttribute(name = "HJSZSS")
    public String getHjszss() {
        return hjszss;
    }

    public void setHjszss(String hjszss) {
        this.hjszss = hjszss;
    }
    @XmlAttribute(name = "XB")
    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }
    @XmlAttribute(name = "DH")
    public String getDh() {
        return dh;
    }

    public void setDh(String dh) {
        this.dh = dh;
    }
    @XmlAttribute(name = "DZ")
    public String getDz() {
        return dz;
    }

    public void setDz(String dz) {
        this.dz = dz;
    }
    @XmlAttribute(name = "YB")
    public String getYb() {
        return yb;
    }

    public void setYb(String yb) {
        this.yb = yb;
    }
    @XmlAttribute(name = "GZDW")
    public String getGzdw() {
        return gzdw;
    }

    public void setGzdw(String gzdw) {
        this.gzdw = gzdw;
    }
    @XmlAttribute(name = "DZYJ")
    public String getDzyj() {
        return dzyj;
    }

    public void setDzyj(String dzyj) {
        this.dzyj = dzyj;
    }
    @XmlAttribute(name = "SFGYR")
    public String getSfgyr() {
        return sfgyr;
    }

    public void setSfgyr(String sfgyr) {
        this.sfgyr = sfgyr;
    }
    @XmlAttribute(name = "BZ")
    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}

==> estateplat-common-1.2.4-20220623.023435-1052-sources.jar: cn/gtmap/estateplat/model/exchange/national/newStandard/ZttGyJtcyNew.java <==
package cn.gtmap.estateplat.model.exchange.national.newStandard;

import cn.gtmap.estateplat.model.exchange.national.AccessData;
import cn.gtmap.estateplat.utils.JaxbNotNullIntegerAdapter;

import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;

/**
 * @author <a href="mailto:zhangyu@gtmap.cn">zhangyu</a>
 * @version 1.0, 2021/10/14
 * @description
 */
@XmlRootElement(name = "ZTT_GY_JTCY")
@Table(name = "ZTF_GY_QL_JTCY")
public class ZttGyJtcyNew implements Serializable, AccessData {
    final static String ysdm = "6003050000";
    private String bdcdyh;
    private String ywh;
    private Integer sxh;
    private String cbfbm;
    private String cyxm;
    private String jtgxdm;
    private String sfzhm;
    private String fzjg;
    private String sshy;
    private String gj;
    private String hjszss;
    private String xb;
    private String dh;
    private String dz;
    private String yb;
    private String gzdw;
    private String dzyj;
    private String sfgyr;
    private String bz;
    @XmlAttribute(name = "YSDM")
    public String getYsdm() {
        return ysdm;
    }

    @XmlAttribute(name = "BDCDYH")
    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }
    @XmlAttribute(name = "YWH")
    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }
    @XmlAttribute(name = "SXH")
    @XmlJavaTypeAdapter(JaxbNotNullIntegerAdapter.class)
    public Integer getSxh() {
        return sxh;
    }

    public void setSxh(Integer sxh) {
        this.sxh = sxh;
    }
    @XmlAttribute(name = "CBFBM")
    public String getCbfbm() {
        return cbfbm;
    }

    public void setCbfbm(String cbfbm) {
        this.cbfbm = cbfbm;
    }
    @XmlAttribute(name = "CYXM")
    public String getCyxm() {
        return cyxm;
    }

    public void setCyxm(String cyxm) {
        this.cyxm = cyxm;
    }
    @XmlAttribute(name = "JTGXDM")
    public String getJtgxdm() {
        return jtgxdm;
    }

    public void setJtgxdm(String jtgxdm) {
        this.jtgxdm = jtgxdm;
    }
    @XmlAttribute(name = "SFZHM")
    public String getSfzhm() {
        return sfzhm;
    }

    public void setSfzhm(String sfzhm) {
        this.sfzhm = sfzhm;
    }
    @XmlAttribute(name = "FZJG")
    public String getFzjg() {
        return fzjg;
    }

    public void setFzjg(String fzjg) {
        this.fzjg = fzjg;
    }
    @XmlAttribute(name = "SSHY")
    public String getSshy() {
        return sshy;
    }

    public void setSshy(String sshy) {
        this.sshy = sshy;
    }
    @XmlAttribute(name = "GJ")
    public String getGj() {
        return gj;
    }

    public void setGj(String gj) {
        this.gj = gj;
    }
    @XmlAttribute(name = "HJSZSS")
    public String getHjszss() {
        return hjszss;
    }

    public void setHjszss(String hjszss) {
        this.hjszss = hjszss;
    }
    @XmlAttribute(name = "XB")
    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }
    @XmlAttribute(name = "DH")
    public String getDh() {
        return dh;
    }

    public void setDh(String dh) {
        this.dh = dh;
    }
    @XmlAttribute(name = "DZ")
    public String getDz() {
        return dz;
    }

    public void setDz(String dz) {
        this.dz = dz;
    }
    @XmlAttribute(name = "YB")
    public String getYb() {
        return yb;
    }

    public void setYb(String yb) {
        this.yb = yb;
    }
    @XmlAttribute(name = "GZDW")
    public String getGzdw() {
        return gzdw;
    }

    public void setGzdw(String gzdw) {
        this.gzdw = gzdw;
    }
    @XmlAttribute(name = "DZYJ")
    public String getDzyj() {
        return dzyj;
    }

    public void setDzyj(String dzyj) {
        this.dzyj = dzyj;
    }
    @XmlAttribute(name = "SFGYR")
    public String getSfgyr() {
        return sfgyr;
    }

    public void setSfgyr(String sfgyr) {
        this.sfgyr = sfgyr;
    }
    @XmlAttribute(name = "BZ")
    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}
